@@ -1,5 +1,5 @@
-use vortex_array::compute::{FilterKernel, filter};
-use vortex_array::{Array, ArrayRef};
+use vortex_array::compute::{FilterKernel, FilterKernelAdapter, filter};
+use vortex_array::{Array, ArrayRef, register_kernel};
 use vortex_error::VortexResult;
 use vortex_mask::Mask;
 
@@ -25,6 +25,8 @@ impl FilterKernel for ALPRDEncoding {
     }
 }
 
+register_kernel!(FilterKernelAdapter(ALPRDEncoding).lift());
+
 #[cfg(test)]
 mod test {
     use rstest::rstest;
