@@ -1,5 +1,5 @@
 use vortex_array::arrays::{PrimitiveArray, TemporalArray};
-use vortex_array::compute::try_cast;
+use vortex_array::compute::cast;
 use vortex_array::{Array, ArrayRef, IntoArray, ToCanonical};
 use vortex_buffer::BufferMut;
 use vortex_dtype::{DType, PType};
@@ -22,7 +22,7 @@ pub fn split_temporal(array: TemporalArray) -> VortexResult<TemporalParts> {
     let validity = temporal_values.validity().clone();
 
     // After this operation, timestamps will be non-nullable PrimitiveArray<i64>
-    let timestamps = try_cast(
+    let timestamps = cast(
         &temporal_values,
         &DType::Primitive(PType::I64, temporal_values.dtype().nullability()),
     )?
