@@ -1,8 +1,8 @@
 use vortex_array::arrays::ConstantArray;
 use vortex_array::builders::builder_with_capacity;
-use vortex_array::compute::{CompareFn, Operator, compare, try_cast};
+use vortex_array::compute::{CompareKernel, CompareKernelAdapter, Operator, cast, compare};
 use vortex_array::validity::Validity;
-use vortex_array::{Array, ArrayRef, ToCanonical};
+use vortex_array::{Array, ArrayRef, ToCanonical, register_kernel};
 use vortex_dtype::{DType, Nullability};
 use vortex_error::VortexResult;
 use vortex_mask::{AllOr, Mask};
@@ -10,7 +10,7 @@ use vortex_scalar::Scalar;
 
 use crate::{DictArray, DictEncoding};
 
-impl CompareFn<&DictArray> for DictEncoding {
+impl CompareKernel for DictEncoding {
     fn compare(
         &self,
         lhs: &DictArray,
@@ -45,6 +45,8 @@ impl CompareFn<&DictArray> for DictEncoding {
     }
 }
 
+register_kernel!(CompareKernelAdapter(DictEncoding).lift());
+
 fn dict_equal_to(
     values_compare: ArrayRef,
     codes: &ArrayRef,
@@ -100,10 +102,10 @@ fn dict_equal_to(
         },
         // We found a single matching value so we can compare the codes directly.
         // Note: the codes include nullability so we can just compare the codes directly, to the found code.
-        (Some(code), None) => try_cast(
+        (Some(code), None) => cast(
             &compare(
                 codes,
-                &try_cast(&ConstantArray::new(code, codes.len()), codes.dtype())?,
+                &cast(&ConstantArray::new(code, codes.len()), codes.dtype())?,
                 Operator::Eq,
             )?,
             &DType::Bool(result_nullability),
