@@ -1,6 +1,6 @@
 use vortex_array::ArrayVariantsImpl;
 use vortex_array::variants::{
-    BinaryArrayTrait, BoolArrayTrait, PrimitiveArrayTrait, Utf8ArrayTrait,
+    BinaryArrayTrait, BoolArrayTrait, DecimalArrayTrait, PrimitiveArrayTrait, Utf8ArrayTrait,
 };
 
 use crate::DictArray;
@@ -21,6 +21,10 @@ impl ArrayVariantsImpl for DictArray {
     fn _as_binary_typed(&self) -> Option<&dyn BinaryArrayTrait> {
         Some(self)
     }
+
+    fn _as_decimal_typed(&self) -> Option<&dyn DecimalArrayTrait> {
+        Some(self)
+    }
 }
 
 impl BoolArrayTrait for DictArray {}
@@ -30,3 +34,5 @@ impl PrimitiveArrayTrait for DictArray {}
 impl Utf8ArrayTrait for DictArray {}
 
 impl BinaryArrayTrait for DictArray {}
+
+impl DecimalArrayTrait for DictArray {}
