@@ -4,9 +4,9 @@ use std::mem::MaybeUninit;
 use arrow_buffer::ArrowNativeType;
 use fastlanes::BitPacking;
 use vortex_array::arrays::PrimitiveArray;
-use vortex_array::compute::{FilterKernel, filter};
+use vortex_array::compute::{FilterKernel, FilterKernelAdapter, filter};
 use vortex_array::variants::PrimitiveArrayTrait;
-use vortex_array::{Array, ArrayRef, ToCanonical};
+use vortex_array::{Array, ArrayRef, ToCanonical, register_kernel};
 use vortex_buffer::{Buffer, BufferMut};
 use vortex_dtype::{NativePType, match_each_unsigned_integer_ptype};
 use vortex_error::{VortexExpect, VortexResult};
@@ -25,6 +25,8 @@ impl FilterKernel for BitPackedEncoding {
     }
 }
 
+register_kernel!(FilterKernelAdapter(BitPackedEncoding).lift());
+
 /// Specialized filter kernel for primitive bit-packed arrays.
 ///
 /// Because the FastLanes bit-packing kernels are only implemented for unsigned types, the provided
