@@ -3,13 +3,12 @@ mod is_constant;
 
 use num_traits::WrappingSub;
 use vortex_array::compute::{
-    CompareFn, FilterKernel, FilterKernelAdapter, IsConstantFn, KernelRef, ScalarAtFn,
-    SearchResult, SearchSortedFn, SearchSortedSide, SliceFn, TakeFn, filter, scalar_at,
-    search_sorted, slice, take,
+    FilterKernel, FilterKernelAdapter, IsConstantFn, ScalarAtFn, SearchResult, SearchSortedFn,
+    SearchSortedSide, SliceFn, TakeFn, filter, scalar_at, search_sorted, slice, take,
 };
 use vortex_array::variants::PrimitiveArrayTrait;
 use vortex_array::vtable::ComputeVTable;
-use vortex_array::{Array, ArrayComputeImpl, ArrayRef};
+use vortex_array::{Array, ArrayRef, register_kernel};
 use vortex_dtype::{NativePType, match_each_integer_ptype};
 use vortex_error::{VortexError, VortexExpect as _, VortexResult};
 use vortex_mask::Mask;
@@ -17,15 +16,7 @@ use vortex_scalar::{PValue, Scalar};
 
 use crate::{FoRArray, FoREncoding};
 
-impl ArrayComputeImpl for FoRArray {
-    const FILTER: Option<KernelRef> = FilterKernelAdapter(FoREncoding).some();
-}
-
 impl ComputeVTable for FoREncoding {
-    fn compare_fn(&self) -> Option<&dyn CompareFn<&dyn Array>> {
-        Some(self)
-    }
-
     fn is_constant_fn(&self) -> Option<&dyn IsConstantFn<&dyn Array>> {
         Some(self)
     }
@@ -67,6 +58,8 @@ impl FilterKernel for FoREncoding {
     }
 }
 
+register_kernel!(FilterKernelAdapter(FoREncoding).lift());
+
 impl ScalarAtFn<&FoRArray> for FoREncoding {
     fn scalar_at(&self, array: &FoRArray, index: usize) -> VortexResult<Scalar> {
         let encoded_pvalue = scalar_at(array.encoded(), index)?.reinterpret_cast(array.ptype());
