@@ -1,17 +1,17 @@
 use vortex_array::arrays::ConstantArray;
-use vortex_array::compute::{BinaryNumericFn, binary_numeric};
-use vortex_array::{Array, ArrayRef};
+use vortex_array::compute::{NumericKernel, NumericKernelAdapter, numeric};
+use vortex_array::{Array, ArrayRef, register_kernel};
 use vortex_error::VortexResult;
-use vortex_scalar::BinaryNumericOperator;
+use vortex_scalar::NumericOperator;
 
 use crate::{RunEndArray, RunEndEncoding};
 
-impl BinaryNumericFn<&RunEndArray> for RunEndEncoding {
-    fn binary_numeric(
+impl NumericKernel for RunEndEncoding {
+    fn numeric(
         &self,
         array: &RunEndArray,
         rhs: &dyn Array,
-        op: BinaryNumericOperator,
+        op: NumericOperator,
     ) -> VortexResult<Option<ArrayRef>> {
         let Some(rhs_scalar) = rhs.as_constant() else {
             return Ok(None);
@@ -22,7 +22,7 @@ impl BinaryNumericFn<&RunEndArray> for RunEndEncoding {
         Ok(Some(
             RunEndArray::with_offset_and_length(
                 array.ends().clone(),
-                binary_numeric(array.values(), &rhs_const_array, op)?,
+                numeric(array.values(), &rhs_const_array, op)?,
                 array.offset(),
                 array.len(),
             )?
@@ -31,11 +31,13 @@ impl BinaryNumericFn<&RunEndArray> for RunEndEncoding {
     }
 }
 
+register_kernel!(NumericKernelAdapter(RunEndEncoding).lift());
+
 #[cfg(test)]
 mod tests {
     use vortex_array::Array;
     use vortex_array::arrays::PrimitiveArray;
-    use vortex_array::compute::conformance::binary_numeric::test_binary_numeric;
+    use vortex_array::compute::conformance::binary_numeric::test_numeric;
 
     use crate::RunEndArray;
 
@@ -49,6 +51,6 @@ mod tests {
     #[test]
     fn test_runend_binary_numeric() {
         let array = ree_array().into_array();
-        test_binary_numeric::<i32>(array)
+        test_numeric::<i32>(array)
     }
 }
