@@ -1,6 +1,6 @@
 use vortex_array::variants::{
-    BinaryArrayTrait, BoolArrayTrait, ExtensionArrayTrait, ListArrayTrait, NullArrayTrait,
-    PrimitiveArrayTrait, StructArrayTrait, Utf8ArrayTrait,
+    BinaryArrayTrait, BoolArrayTrait, DecimalArrayTrait, ExtensionArrayTrait, ListArrayTrait,
+    NullArrayTrait, PrimitiveArrayTrait, StructArrayTrait, Utf8ArrayTrait,
 };
 use vortex_array::{Array, ArrayVariants, ArrayVariantsImpl};
 use vortex_dtype::FieldName;
@@ -23,6 +23,10 @@ impl ArrayVariantsImpl for SparseArray {
         Some(self)
     }
 
+    fn _as_decimal_typed(&self) -> Option<&dyn DecimalArrayTrait> {
+        Some(self)
+    }
+
     fn _as_utf8_typed(&self) -> Option<&dyn Utf8ArrayTrait> {
         Some(self)
     }
@@ -54,6 +58,8 @@ impl Utf8ArrayTrait for SparseArray {}
 
 impl BinaryArrayTrait for SparseArray {}
 
+impl DecimalArrayTrait for SparseArray {}
+
 impl StructArrayTrait for SparseArray {
     fn maybe_null_field_by_idx(&self, idx: usize) -> VortexResult<ArrayRef> {
         let new_patches = self.patches().clone().map_values(|values| {
