@@ -1,10 +1,9 @@
 use vortex_array::compute::{
-    FilterKernel, FilterKernelAdapter, KernelRef, ScalarAtFn, SliceFn, TakeFn, filter, scalar_at,
-    slice, take,
+    FilterKernel, FilterKernelAdapter, ScalarAtFn, SliceFn, TakeFn, filter, scalar_at, slice, take,
 };
 use vortex_array::variants::PrimitiveArrayTrait;
 use vortex_array::vtable::ComputeVTable;
-use vortex_array::{Array, ArrayComputeImpl, ArrayRef};
+use vortex_array::{Array, ArrayRef, register_kernel};
 use vortex_dtype::match_each_unsigned_integer_ptype;
 use vortex_error::{VortexResult, vortex_err};
 use vortex_mask::Mask;
@@ -13,10 +12,6 @@ use zigzag::{ZigZag as ExternalZigZag, ZigZag};
 
 use crate::{ZigZagArray, ZigZagEncoding};
 
-impl ArrayComputeImpl for ZigZagArray {
-    const FILTER: Option<KernelRef> = FilterKernelAdapter(ZigZagEncoding).some();
-}
-
 impl ComputeVTable for ZigZagEncoding {
     fn scalar_at_fn(&self) -> Option<&dyn ScalarAtFn<&dyn Array>> {
         Some(self)
@@ -38,6 +33,8 @@ impl FilterKernel for ZigZagEncoding {
     }
 }
 
+register_kernel!(FilterKernelAdapter(ZigZagEncoding).lift());
+
 impl ScalarAtFn<&ZigZagArray> for ZigZagEncoding {
     fn scalar_at(&self, array: &ZigZagArray, index: usize) -> VortexResult<Scalar> {
         let scalar = scalar_at(array.encoded(), index)?;
