@@ -10,8 +10,8 @@ use vortex::mask::Mask;
 use vortex::stats::StatsSetRef;
 use vortex::vtable::VTableRef;
 use vortex::{
-    ArrayCanonicalImpl, ArrayComputeImpl, ArrayImpl, ArrayStatisticsImpl, ArrayValidityImpl,
-    ArrayVariantsImpl, ArrayVisitorImpl, Canonical, EmptyMetadata,
+    ArrayCanonicalImpl, ArrayImpl, ArrayStatisticsImpl, ArrayValidityImpl, ArrayVariantsImpl,
+    ArrayVisitorImpl, Canonical, EmptyMetadata,
 };
 
 use crate::arrays::py::PyEncodingClass;
@@ -56,8 +56,6 @@ impl ArrayCanonicalImpl for PyArrayInstance {
     }
 }
 
-impl ArrayComputeImpl for PyArrayInstance {}
-
 impl ArrayStatisticsImpl for PyArrayInstance {
     fn _stats_ref(&self) -> StatsSetRef<'_> {
         todo!()
