@@ -1,5 +1,4 @@
 mod canonical;
-mod compute;
 mod convert;
 mod implementation;
 mod statistics;
@@ -12,7 +11,6 @@ use std::fmt::{Debug, Display, Formatter};
 use std::sync::Arc;
 
 pub use canonical::*;
-pub use compute::*;
 pub use convert::*;
 pub use implementation::*;
 pub use statistics::*;
@@ -28,7 +26,7 @@ use crate::arrays::{
     VarBinEncoding, VarBinViewEncoding,
 };
 use crate::builders::ArrayBuilder;
-use crate::compute::{ComputeFn, KernelRef};
+use crate::compute::{ComputeFn, InvocationArgs, Output};
 use crate::stats::StatsSetRef;
 use crate::vtable::{EncodingVTable, VTableRef};
 use crate::{Canonical, EncodingId};
@@ -70,9 +68,6 @@ pub trait Array: Send + Sync + Debug + ArrayStatistics + ArrayVariants + ArrayVi
     /// Returns the encoding VTable.
     fn vtable(&self) -> VTableRef;
 
-    /// Attempts to find a kernel for the given compute invocation.
-    fn find_kernel(&self, compute_fn: &dyn ComputeFn) -> Option<KernelRef>;
-
     /// Returns whether the array is of the given encoding.
     fn is_encoding(&self, encoding: EncodingId) -> bool {
         self.encoding() == encoding
@@ -139,6 +134,25 @@ pub trait Array: Send + Sync + Debug + ArrayStatistics + ArrayVariants + ArrayVi
 
     /// Replaces the children of the array with the given array references.
     fn with_children(&self, children: &[ArrayRef]) -> VortexResult<ArrayRef>;
+
+    /// Optionally invoke a kernel for the given compute function.
+    ///
+    /// These encoding-specific kernels are independent of kernels registered directly with
+    /// compute functions using [`ComputeFn::register_kernel`], and are attempted only if none of
+    /// the function-specific kernels returns a result.
+    ///
+    /// This allows encodings the opportunity to generically implement many compute functions
+    /// that share some property, for example [`ComputeFn::is_elementwise`], without prior
+    /// knowledge of the function itself, while still allowing users to override the implementation
+    /// of compute functions for built-in encodings. For an example, see the implementation for
+    /// chunked arrays.
+    ///
+    /// The first input in the [`InvocationArgs`] is always the array itself.
+    ///
+    /// Warning: do not call `compute_fn.invoke(args)` directly, as this will result in a recursive
+    /// call.
+    fn invoke(&self, compute_fn: &ComputeFn, args: &InvocationArgs)
+    -> VortexResult<Option<Output>>;
 }
 
 impl Array for Arc<dyn Array> {
@@ -174,10 +188,6 @@ impl Array for Arc<dyn Array> {
         self.as_ref().vtable()
     }
 
-    fn find_kernel(&self, compute_fn: &dyn ComputeFn) -> Option<KernelRef> {
-        self.as_ref().find_kernel(compute_fn)
-    }
-
     fn is_valid(&self, index: usize) -> VortexResult<bool> {
         self.as_ref().is_valid(index)
     }
@@ -221,6 +231,14 @@ impl Array for Arc<dyn Array> {
     fn with_children(&self, children: &[ArrayRef]) -> VortexResult<ArrayRef> {
         self.as_ref().with_children(children)
     }
+
+    fn invoke(
+        &self,
+        compute_fn: &ComputeFn,
+        args: &InvocationArgs,
+    ) -> VortexResult<Option<Output>> {
+        self.as_ref().invoke(compute_fn, args)
+    }
 }
 
 /// A reference counted pointer to a dynamic [`Array`] trait object.
