@@ -3,9 +3,10 @@ use vortex_error::{VortexResult, vortex_bail};
 
 use crate::array::{Array, ArrayRef};
 use crate::arrays::{BoolArray, BoolEncoding};
-use crate::compute::CastFn;
+use crate::compute::{CastKernel, CastKernelAdapter};
+use crate::register_kernel;
 
-impl CastFn<&BoolArray> for BoolEncoding {
+impl CastKernel for BoolEncoding {
     fn cast(&self, array: &BoolArray, dtype: &DType) -> VortexResult<ArrayRef> {
         if !matches!(dtype, DType::Bool(_)) {
             vortex_bail!("Cannot cast {} to {}", array.dtype(), dtype);
@@ -17,18 +18,20 @@ impl CastFn<&BoolArray> for BoolEncoding {
     }
 }
 
+register_kernel!(CastKernelAdapter(BoolEncoding).lift());
+
 #[cfg(test)]
 mod tests {
     use vortex_dtype::{DType, Nullability};
 
     use crate::arrays::BoolArray;
-    use crate::compute::try_cast;
+    use crate::compute::cast;
 
     #[test]
     fn try_cast_bool_success() {
         let bool = BoolArray::from_iter(vec![Some(true), Some(false), Some(true)]);
 
-        let res = try_cast(&bool, &DType::Bool(Nullability::NonNullable));
+        let res = cast(&bool, &DType::Bool(Nullability::NonNullable));
         assert!(res.is_ok());
         assert_eq!(res.unwrap().dtype(), &DType::Bool(Nullability::NonNullable));
     }
@@ -37,6 +40,6 @@ mod tests {
     #[should_panic]
     fn try_cast_bool_fail() {
         let bool = BoolArray::from_iter(vec![Some(true), Some(false), None]);
-        try_cast(&bool, &DType::Bool(Nullability::NonNullable)).unwrap();
+        cast(&bool, &DType::Bool(Nullability::NonNullable)).unwrap();
     }
 }
