@@ -3,8 +3,8 @@ use vortex_error::{VortexExpect, VortexResult};
 use vortex_mask::{Mask, MaskIter};
 
 use crate::arrays::{BoolArray, BoolEncoding};
-use crate::compute::FilterKernel;
-use crate::{Array, ArrayRef};
+use crate::compute::{FilterKernel, FilterKernelAdapter};
+use crate::{Array, ArrayRef, register_kernel};
 
 /// If the filter density is above 80%, we use slices to filter the array instead of indices.
 const FILTER_SLICES_DENSITY_THRESHOLD: f64 = 0.8;
@@ -34,6 +34,8 @@ impl FilterKernel for BoolEncoding {
     }
 }
 
+register_kernel!(FilterKernelAdapter(BoolEncoding).lift());
+
 /// Select indices from a boolean buffer.
 /// NOTE: it was benchmarked to be faster using collect_bool to index into a slice than to
 ///  pass the indices as an iterator of usize. So we keep this alternate implementation.
