@@ -7,12 +7,18 @@ use vortex_error::{VortexExpect, VortexResult, vortex_err};
 use super::ChunkedArray;
 use crate::arrays::{ListArray, PrimitiveArray, StructArray};
 use crate::builders::{ArrayBuilder, builder_with_capacity};
-use crate::compute::{scalar_at, slice, try_cast};
+use crate::compute::{cast, scalar_at, slice};
 use crate::validity::Validity;
 use crate::{Array as _, ArrayCanonicalImpl, ArrayRef, Canonical, ToCanonical};
 
 impl ArrayCanonicalImpl for ChunkedArray {
     fn _to_canonical(&self) -> VortexResult<Canonical> {
+        if self.nchunks() == 0 {
+            return Ok(Canonical::empty(self.dtype()));
+        }
+        if self.nchunks() == 1 {
+            return self.chunks()[0].to_canonical();
+        }
         match self.dtype() {
             DType::Struct(struct_dtype, _) => {
                 let struct_array = swizzle_struct_chunks(
@@ -83,7 +89,7 @@ fn pack_lists(
     for chunk in chunks {
         let chunk = chunk.to_list()?;
         // TODO: handle i32 offsets if they fit.
-        let offsets_arr = try_cast(
+        let offsets_arr = cast(
             chunk.offsets(),
             &DType::Primitive(PType::I64, Nullability::NonNullable),
         )?
