@@ -3,9 +3,11 @@ use vortex_error::{VortexExpect, VortexResult, VortexUnwrap};
 use vortex_mask::{Mask, MaskIter};
 
 use crate::arrays::{ChunkedArray, ChunkedEncoding, PrimitiveArray};
-use crate::compute::{FilterKernel, SearchSorted, SearchSortedSide, filter, take};
+use crate::compute::{
+    FilterKernel, FilterKernelAdapter, SearchSorted, SearchSortedSide, filter, take,
+};
 use crate::validity::Validity;
-use crate::{Array, ArrayRef};
+use crate::{Array, ArrayRef, register_kernel};
 
 // This is modeled after the constant with the equivalent name in arrow-rs.
 pub(crate) const FILTER_SLICES_SELECTIVITY_THRESHOLD: f64 = 0.8;
@@ -27,6 +29,8 @@ impl FilterKernel for ChunkedEncoding {
     }
 }
 
+register_kernel!(FilterKernelAdapter(ChunkedEncoding).lift());
+
 /// The filter to apply to each chunk.
 ///
 /// When we rewrite a set of slices in a filter predicate into chunk addresses, we want to account
