@@ -3,18 +3,20 @@ use vortex_buffer::{Buffer, BufferMut, buffer};
 use vortex_dtype::{DType, Nullability, PType, match_each_native_ptype};
 use vortex_error::{VortexExpect, VortexResult};
 use vortex_scalar::{
-    BinaryScalar, BoolScalar, ExtScalar, ListScalar, Scalar, ScalarValue, StructScalar, Utf8Scalar,
+    BinaryScalar, BoolScalar, DecimalValue, ExtScalar, ListScalar, Scalar, ScalarValue,
+    StructScalar, Utf8Scalar,
 };
 
 use crate::array::ArrayCanonicalImpl;
 use crate::arrays::constant::ConstantArray;
 use crate::arrays::primitive::PrimitiveArray;
 use crate::arrays::{
-    BinaryView, BoolArray, ExtensionArray, ListArray, NullArray, StructArray, VarBinViewArray,
+    BinaryView, BoolArray, DecimalArray, ExtensionArray, ListArray, NullArray, StructArray,
+    VarBinViewArray, precision_to_storage_size,
 };
 use crate::builders::{ArrayBuilderExt, builder_with_capacity};
 use crate::validity::Validity;
-use crate::{Array, Canonical, IntoArray};
+use crate::{Array, Canonical, IntoArray, match_each_decimal_value, match_each_decimal_value_type};
 
 impl ArrayCanonicalImpl for ConstantArray {
     fn _to_canonical(&self) -> VortexResult<Canonical> {
@@ -54,6 +56,29 @@ impl ArrayCanonicalImpl for ConstantArray {
                     ))
                 })
             }
+            DType::Decimal(decimal_type, ..) => {
+                let size = precision_to_storage_size(decimal_type);
+                let decimal = scalar.as_decimal();
+                let Some(value) = decimal.decimal_value() else {
+                    let all_null = match_each_decimal_value_type!(size, |$D| {
+                       DecimalArray::new(
+                                Buffer::<$D>::zeroed(self.len()),
+                                *decimal_type,
+                                Validity::AllInvalid,
+                            )
+                    });
+                    return Ok(Canonical::Decimal(all_null));
+                };
+
+                let decimal_array = match_each_decimal_value!(value, |$V| {
+                   DecimalArray::new(
+                        Buffer::full(*$V, self.len()),
+                        *decimal_type,
+                        Validity::AllValid,
+                    )
+                });
+                Canonical::Decimal(decimal_array)
+            }
             DType::Utf8(_) => {
                 let value = Utf8Scalar::try_from(scalar)?.value();
                 let const_value = value.as_ref().map(|v| v.as_bytes());
