@@ -1,21 +1,19 @@
+mod mask;
 mod to_arrow;
 
 use std::sync::Arc;
 
 use itertools::Itertools;
 use vortex_error::VortexResult;
-use vortex_mask::Mask;
 use vortex_scalar::Scalar;
 
 use crate::arrays::{ListArray, ListEncoding};
 use crate::compute::{
-    IsConstantFn, IsConstantOpts, IsSortedFn, MaskFn, MinMaxFn, MinMaxResult, ScalarAtFn, SliceFn,
+    IsConstantFn, IsConstantOpts, IsSortedFn, MinMaxFn, MinMaxResult, ScalarAtFn, SliceFn,
     ToArrowFn, UncompressedSizeFn, scalar_at, slice, uncompressed_size,
 };
 use crate::vtable::ComputeVTable;
-use crate::{Array, ArrayComputeImpl, ArrayRef};
-
-impl ArrayComputeImpl for ListArray {}
+use crate::{Array, ArrayRef};
 
 impl ComputeVTable for ListEncoding {
     fn is_constant_fn(&self) -> Option<&dyn IsConstantFn<&dyn Array>> {
@@ -34,10 +32,6 @@ impl ComputeVTable for ListEncoding {
         Some(self)
     }
 
-    fn mask_fn(&self) -> Option<&dyn MaskFn<&dyn Array>> {
-        Some(self)
-    }
-
     fn min_max_fn(&self) -> Option<&dyn MinMaxFn<&dyn Array>> {
         Some(self)
     }
@@ -75,17 +69,6 @@ impl SliceFn<&ListArray> for ListEncoding {
     }
 }
 
-impl MaskFn<&ListArray> for ListEncoding {
-    fn mask(&self, array: &ListArray, mask: Mask) -> VortexResult<ArrayRef> {
-        ListArray::try_new(
-            array.elements().clone(),
-            array.offsets().clone(),
-            array.validity().mask(&mask)?,
-        )
-        .map(|a| a.into_array())
-    }
-}
-
 impl MinMaxFn<&ListArray> for ListEncoding {
     fn min_max(&self, _array: &ListArray) -> VortexResult<Option<MinMaxResult>> {
         // TODO(joe): Implement list min max
