@@ -3,13 +3,13 @@ use vortex_mask::Mask;
 
 use crate::arrays::PrimitiveEncoding;
 use crate::arrays::primitive::PrimitiveArray;
-use crate::compute::MaskFn;
+use crate::compute::{MaskKernel, MaskKernelAdapter};
 use crate::variants::PrimitiveArrayTrait as _;
-use crate::{Array, ArrayRef};
+use crate::{Array, ArrayRef, register_kernel};
 
-impl MaskFn<&PrimitiveArray> for PrimitiveEncoding {
-    fn mask(&self, array: &PrimitiveArray, mask: Mask) -> VortexResult<ArrayRef> {
-        let validity = array.validity().mask(&mask)?;
+impl MaskKernel for PrimitiveEncoding {
+    fn mask(&self, array: &PrimitiveArray, mask: &Mask) -> VortexResult<ArrayRef> {
+        let validity = array.validity().mask(mask)?;
         Ok(
             PrimitiveArray::from_byte_buffer(array.byte_buffer().clone(), array.ptype(), validity)
                 .into_array(),
@@ -17,6 +17,8 @@ impl MaskFn<&PrimitiveArray> for PrimitiveEncoding {
     }
 }
 
+register_kernel!(MaskKernelAdapter(PrimitiveEncoding).lift());
+
 #[cfg(test)]
 mod test {
     use crate::arrays::PrimitiveArray;
