@@ -7,10 +7,10 @@ use vortex_mask::{AllOr, Mask, MaskIter};
 use crate::arrays::VarBinEncoding;
 use crate::arrays::varbin::VarBinArray;
 use crate::arrays::varbin::builder::VarBinBuilder;
-use crate::compute::FilterKernel;
+use crate::compute::{FilterKernel, FilterKernelAdapter};
 use crate::validity::Validity;
 use crate::variants::PrimitiveArrayTrait;
-use crate::{Array, ArrayRef, ToCanonical};
+use crate::{Array, ArrayRef, ToCanonical, register_kernel};
 
 impl FilterKernel for VarBinEncoding {
     fn filter(&self, array: &VarBinArray, mask: &Mask) -> VortexResult<ArrayRef> {
@@ -18,6 +18,8 @@ impl FilterKernel for VarBinEncoding {
     }
 }
 
+register_kernel!(FilterKernelAdapter(VarBinEncoding).lift());
+
 fn filter_select_var_bin(arr: &VarBinArray, mask: &Mask) -> VortexResult<VarBinArray> {
     match mask
         .values()
