@@ -3,21 +3,23 @@ use vortex_mask::Mask;
 
 use crate::arrays::VarBinEncoding;
 use crate::arrays::varbin::VarBinArray;
-use crate::compute::MaskFn;
-use crate::{Array, ArrayRef};
+use crate::compute::{MaskKernel, MaskKernelAdapter};
+use crate::{Array, ArrayRef, register_kernel};
 
-impl MaskFn<&VarBinArray> for VarBinEncoding {
-    fn mask(&self, array: &VarBinArray, mask: Mask) -> VortexResult<ArrayRef> {
+impl MaskKernel for VarBinEncoding {
+    fn mask(&self, array: &VarBinArray, mask: &Mask) -> VortexResult<ArrayRef> {
         Ok(VarBinArray::try_new(
             array.offsets().clone(),
             array.bytes().clone(),
             array.dtype().as_nullable(),
-            array.validity().mask(&mask)?,
+            array.validity().mask(mask)?,
         )?
         .into_array())
     }
 }
 
+register_kernel!(MaskKernelAdapter(VarBinEncoding).lift());
+
 #[cfg(test)]
 mod test {
     use vortex_dtype::{DType, Nullability};
