@@ -2,14 +2,13 @@ pub use min_max::compute_min_max;
 use vortex_error::VortexResult;
 use vortex_scalar::Scalar;
 
+use crate::Array;
 use crate::arrays::VarBinEncoding;
 use crate::arrays::varbin::{VarBinArray, varbin_scalar};
 use crate::compute::{
-    CastFn, CompareFn, FilterKernelAdapter, IsConstantFn, IsSortedFn, KernelRef, MaskFn, MinMaxFn,
-    ScalarAtFn, SliceFn, TakeFn, ToArrowFn, UncompressedSizeFn,
+    IsConstantFn, IsSortedFn, MinMaxFn, ScalarAtFn, SliceFn, TakeFn, ToArrowFn, UncompressedSizeFn,
 };
 use crate::vtable::ComputeVTable;
-use crate::{Array, ArrayComputeImpl};
 
 mod cast;
 mod compare;
@@ -23,19 +22,7 @@ mod take;
 pub(crate) mod to_arrow;
 mod uncompressed_size;
 
-impl ArrayComputeImpl for VarBinArray {
-    const FILTER: Option<KernelRef> = FilterKernelAdapter(VarBinEncoding).some();
-}
-
 impl ComputeVTable for VarBinEncoding {
-    fn cast_fn(&self) -> Option<&dyn CastFn<&dyn Array>> {
-        Some(self)
-    }
-
-    fn compare_fn(&self) -> Option<&dyn CompareFn<&dyn Array>> {
-        Some(self)
-    }
-
     fn is_constant_fn(&self) -> Option<&dyn IsConstantFn<&dyn Array>> {
         Some(self)
     }
@@ -44,10 +31,6 @@ impl ComputeVTable for VarBinEncoding {
         Some(self)
     }
 
-    fn mask_fn(&self) -> Option<&dyn MaskFn<&dyn Array>> {
-        Some(self)
-    }
-
     fn scalar_at_fn(&self) -> Option<&dyn ScalarAtFn<&dyn Array>> {
         Some(self)
     }
