@@ -1,13 +1,13 @@
 mod cast;
 mod is_constant;
 mod is_sorted;
+mod mask;
 mod min_max;
 mod optimize;
 mod take;
 mod to_arrow;
 
 use vortex_error::VortexResult;
-use vortex_mask::Mask;
 use vortex_scalar::Scalar;
 
 use super::BinaryView;
@@ -15,22 +15,12 @@ use crate::arrays::VarBinViewEncoding;
 use crate::arrays::varbin::varbin_scalar;
 use crate::arrays::varbinview::VarBinViewArray;
 use crate::compute::{
-    CastFn, IsConstantFn, IsSortedFn, KernelRef, MaskFn, MinMaxFn, ScalarAtFn, SliceFn, TakeFn,
-    ToArrowFn, UncompressedSizeFn,
+    IsConstantFn, IsSortedFn, MinMaxFn, ScalarAtFn, SliceFn, TakeFn, ToArrowFn, UncompressedSizeFn,
 };
 use crate::vtable::ComputeVTable;
-use crate::{Array, ArrayComputeImpl, ArrayRef};
-
-impl ArrayComputeImpl for VarBinViewArray {
-    // No filter implementation because we can trivially fall back to Arrow.
-    const FILTER: Option<KernelRef> = None;
-}
+use crate::{Array, ArrayRef};
 
 impl ComputeVTable for VarBinViewEncoding {
-    fn cast_fn(&self) -> Option<&dyn CastFn<&dyn Array>> {
-        Some(self)
-    }
-
     fn is_constant_fn(&self) -> Option<&dyn IsConstantFn<&dyn Array>> {
         Some(self)
     }
@@ -39,10 +29,6 @@ impl ComputeVTable for VarBinViewEncoding {
         Some(self)
     }
 
-    fn mask_fn(&self) -> Option<&dyn MaskFn<&dyn Array>> {
-        Some(self)
-    }
-
     fn min_max_fn(&self) -> Option<&dyn MinMaxFn<&dyn Array>> {
         Some(self)
     }
@@ -88,18 +74,6 @@ impl SliceFn<&VarBinViewArray> for VarBinViewEncoding {
     }
 }
 
-impl MaskFn<&VarBinViewArray> for VarBinViewEncoding {
-    fn mask(&self, array: &VarBinViewArray, mask: Mask) -> VortexResult<ArrayRef> {
-        Ok(VarBinViewArray::try_new(
-            array.views().clone(),
-            array.buffers().to_vec(),
-            array.dtype().as_nullable(),
-            array.validity().mask(&mask)?,
-        )?
-        .into_array())
-    }
-}
-
 impl UncompressedSizeFn<&VarBinViewArray> for VarBinViewEncoding {
     fn uncompressed_size(&self, array: &VarBinViewArray) -> VortexResult<usize> {
         let views = array.views().len() * size_of::<BinaryView>();
