@@ -3,6 +3,7 @@ use std::any::Any;
 use arrow_buffer::BooleanBufferBuilder;
 use vortex_dtype::{DType, Nullability};
 use vortex_error::{VortexResult, vortex_bail};
+use vortex_mask::Mask;
 
 use crate::arrays::BoolArray;
 use crate::builders::ArrayBuilder;
@@ -85,6 +86,18 @@ impl ArrayBuilder for BoolBuilder {
         Ok(())
     }
 
+    fn ensure_capacity(&mut self, capacity: usize) {
+        if capacity > self.inner.capacity() {
+            self.nulls.ensure_capacity(capacity);
+            self.inner.reserve(capacity - self.inner.capacity());
+        }
+    }
+
+    fn set_validity(&mut self, validity: Mask) {
+        self.nulls = LazyNullBufferBuilder::new(validity.len());
+        self.nulls.append_validity_mask(validity);
+    }
+
     fn finish(&mut self) -> ArrayRef {
         assert_eq!(
             self.nulls.len(),
