@@ -6,7 +6,8 @@ use vortex_dtype::DType;
 use vortex_error::{VortexExpect, VortexResult, vortex_bail};
 
 use crate::arrays::{
-    BoolArray, ExtensionArray, ListArray, NullArray, PrimitiveArray, StructArray, VarBinViewArray,
+    BoolArray, DecimalArray, ExtensionArray, ListArray, NullArray, PrimitiveArray, StructArray,
+    VarBinViewArray,
 };
 use crate::arrow::IntoArrowArray;
 use crate::builders::builder_with_capacity;
@@ -41,6 +42,7 @@ pub enum Canonical {
     Null(NullArray),
     Bool(BoolArray),
     Primitive(PrimitiveArray),
+    Decimal(DecimalArray),
     Struct(StructArray),
     // TODO(joe): maybe this should be a ListView, however this will be annoying in spiral
     List(ListArray),
@@ -81,6 +83,13 @@ impl Canonical {
         }
     }
 
+    pub fn into_decimal(self) -> VortexResult<DecimalArray> {
+        match self {
+            Canonical::Decimal(a) => Ok(a),
+            _ => vortex_bail!("Cannot unwrap DecimalArray from {:?}", &self),
+        }
+    }
+
     pub fn into_struct(self) -> VortexResult<StructArray> {
         match self {
             Canonical::Struct(a) => Ok(a),
@@ -116,6 +125,7 @@ impl AsRef<dyn Array> for Canonical {
             Canonical::Null(a) => a,
             Canonical::Bool(a) => a,
             Canonical::Primitive(a) => a,
+            Canonical::Decimal(a) => a,
             Canonical::Struct(a) => a,
             Canonical::List(a) => a,
             Canonical::VarBinView(a) => a,
@@ -130,6 +140,7 @@ impl IntoArray for Canonical {
             Canonical::Null(a) => a.into_array(),
             Canonical::Bool(a) => a.into_array(),
             Canonical::Primitive(a) => a.into_array(),
+            Canonical::Decimal(a) => a.into_array(),
             Canonical::Struct(a) => a.into_array(),
             Canonical::List(a) => a.into_array(),
             Canonical::VarBinView(a) => a.into_array(),
@@ -156,6 +167,10 @@ pub trait ToCanonical: Array {
         self.to_canonical()?.into_primitive()
     }
 
+    fn to_decimal(&self) -> VortexResult<DecimalArray> {
+        self.to_canonical()?.into_decimal()
+    }
+
     fn to_struct(&self) -> VortexResult<StructArray> {
         self.to_canonical()?.into_struct()
     }
@@ -199,6 +214,7 @@ impl From<Canonical> for ArrayRef {
             Canonical::Null(a) => a.into_array(),
             Canonical::Bool(a) => a.into_array(),
             Canonical::Primitive(a) => a.into_array(),
+            Canonical::Decimal(a) => a.into_array(),
             Canonical::Struct(a) => a.into_array(),
             Canonical::List(a) => a.into_array(),
             Canonical::VarBinView(a) => a.into_array(),
