@@ -6,6 +6,7 @@
 //! This crate contains the core logical type system for Vortex, including the definition of data types,
 //! and (optionally) logic for their serialization and deserialization.
 
+pub use decimal::*;
 pub use dtype::*;
 pub use extension::*;
 pub use field::*;
@@ -20,6 +21,7 @@ mod arbitrary;
 #[cfg(feature = "arrow")]
 pub mod arrow;
 pub mod datetime;
+mod decimal;
 mod dtype;
 mod extension;
 mod field;
@@ -29,7 +31,6 @@ mod ptype;
 mod serde;
 mod struct_;
 
-#[cfg(feature = "proto")]
 pub mod proto {
     //! Protocol buffer representations for DTypes
     //!
