@@ -9,7 +9,7 @@ use std::sync::Arc;
 use flatbuffers::{FlatBufferBuilder, WIPOffset};
 use vortex_array::ArrayContext;
 use vortex_flatbuffers::{FlatBufferRoot, WriteFlatBuffer, footer as fb};
-use vortex_layout::{Layout, LayoutContext};
+use vortex_layout::LayoutContext;
 
 use crate::footer::segment::SegmentSpec;
 
@@ -17,28 +17,24 @@ use crate::footer::segment::SegmentSpec;
 ///
 /// This struct is used to write the layout component of a Vortex file footer,
 /// which describes the structure of the data in the file.
-pub(crate) struct FileLayoutFlatBufferWriter {
+pub(crate) struct FooterFlatBufferWriter {
     /// The array context containing encodings used in the file.
     pub(crate) ctx: ArrayContext,
-    /// The root layout of the file.
-    pub(crate) layout: Layout,
+    /// The layout context containing the layouts used in the file.
+    pub(crate) layout_ctx: LayoutContext,
     /// Specifications for all segments in the file.
     pub(crate) segment_specs: Arc<[SegmentSpec]>,
 }
 
-impl FlatBufferRoot for FileLayoutFlatBufferWriter {}
+impl FlatBufferRoot for FooterFlatBufferWriter {}
 
-impl WriteFlatBuffer for FileLayoutFlatBufferWriter {
-    type Target<'a> = fb::FileLayout<'a>;
+impl WriteFlatBuffer for FooterFlatBufferWriter {
+    type Target<'a> = fb::Footer<'a>;
 
     fn write_flatbuffer<'fb>(
         &self,
         fbb: &mut FlatBufferBuilder<'fb>,
     ) -> WIPOffset<Self::Target<'fb>> {
-        // Set up a layout context to capture the layouts used in the file.
-        let layout_ctx = LayoutContext::empty();
-        let layout = self.layout.write_flatbuffer(fbb, &layout_ctx);
-
         let segment_specs =
             fbb.create_vector_from_iter(self.segment_specs.iter().map(fb::SegmentSpec::from));
 
@@ -53,7 +49,8 @@ impl WriteFlatBuffer for FileLayoutFlatBufferWriter {
             .collect::<Vec<_>>();
         let array_specs = fbb.create_vector(array_specs.as_slice());
 
-        let layout_specs = layout_ctx
+        let layout_specs = self
+            .layout_ctx
             .encodings()
             .iter()
             .map(|e| {
@@ -63,10 +60,9 @@ impl WriteFlatBuffer for FileLayoutFlatBufferWriter {
             .collect::<Vec<_>>();
         let layout_specs = fbb.create_vector(layout_specs.as_slice());
 
-        fb::FileLayout::create(
+        fb::Footer::create(
             fbb,
-            &fb::FileLayoutArgs {
-                layout: Some(layout),
+            &fb::FooterArgs {
                 segment_specs: Some(segment_specs),
                 array_specs: Some(array_specs),
                 layout_specs: Some(layout_specs),
