@@ -1,6 +1,7 @@
 use std::io::Read;
 
 use bytes::BytesMut;
+use vortex_array::ArrayRegistry;
 use vortex_error::VortexResult;
 
 use crate::messages::{DecoderMessage, MessageDecoder, PollRead};
@@ -13,11 +14,11 @@ pub struct SyncMessageReader<R> {
 }
 
 impl<R: Read> SyncMessageReader<R> {
-    pub fn new(read: R) -> Self {
+    pub fn new(read: R, registry: ArrayRegistry) -> Self {
         SyncMessageReader {
             read,
             buffer: BytesMut::new(),
-            decoder: MessageDecoder::default(),
+            decoder: MessageDecoder::new(registry),
         }
     }
 }
