@@ -1,6 +1,7 @@
 use vortex_array::{VTableContext, VTableRegistry};
 
 use crate::layouts::chunked::ChunkedLayout;
+use crate::layouts::dict::DictLayout;
 use crate::layouts::flat::FlatLayout;
 use crate::layouts::stats::StatsLayout;
 use crate::layouts::struct_::StructLayout;
@@ -21,6 +22,7 @@ impl LayoutRegistryExt for LayoutRegistry {
             LayoutVTableRef::new_ref(&FlatLayout),
             LayoutVTableRef::new_ref(&StructLayout),
             LayoutVTableRef::new_ref(&StatsLayout),
+            LayoutVTableRef::new_ref(&DictLayout),
         ]);
         this
     }
