@@ -6,6 +6,7 @@ use vortex_dtype::{DType, PType};
 use vortex_error::{VortexError, vortex_bail, vortex_err};
 
 use crate::Scalar;
+use crate::decimal::DecimalValue;
 
 macro_rules! value_to_arrow_scalar {
     ($V:expr, $AR:ty) => {
@@ -72,6 +73,20 @@ impl TryFrom<&Scalar> for Arc<dyn Datum> {
                         .unwrap_or_else(|| Arc::new(Float64Array::new_null(1))),
                 })
             }
+            DType::Decimal(..) => match value.as_decimal().decimal_value() {
+                // TODO(joe): replace with decimal32, etc.
+                Some(DecimalValue::I8(v)) => Ok(Arc::new(Decimal128Array::new_scalar(*v as i128))),
+                Some(DecimalValue::I16(v)) => Ok(Arc::new(Decimal128Array::new_scalar(*v as i128))),
+                Some(DecimalValue::I32(v)) => Ok(Arc::new(Decimal128Array::new_scalar(*v as i128))),
+                Some(DecimalValue::I64(v)) => Ok(Arc::new(Decimal128Array::new_scalar(*v as i128))),
+                Some(DecimalValue::I128(v128)) => Ok(Arc::new(Decimal128Array::new_scalar(*v128))),
+                Some(DecimalValue::I256(v256)) => {
+                    Ok(Arc::new(Decimal256Array::new_scalar((*v256).into())))
+                }
+                None => Ok(Arc::new(arrow_array::Scalar::new(
+                    Decimal128Array::new_null(1),
+                ))),
+            },
             DType::Utf8(_) => {
                 value_to_arrow_scalar!(value.as_utf8().value(), StringViewArray)
             }
